pub struct Exchange {
pub secretion: Vec<f64>,
pub uptake: Vec<f64>,
}Expand description
Secretion and uptake for one cell type, in the order of Fields::species.
Fields
secretion: Vec<f64>Amount added to each site the cell owns, per step.
uptake: Vec<f64>Fraction removed from each site the cell owns, per step.