pub struct Fields {
pub species: Vec<Species>,
pub values: Vec<Vec<f64>>,
pub substeps: Vec<usize>,
/* private fields */
}Expand description
Every species, and the concentrations on the lattice.
Fields
species: Vec<Species>The species, in the order a description lists them.
values: Vec<Vec<f64>>One concentration grid per species, indexed as the lattice is.
substeps: Vec<usize>Diffusion sub-steps per Monte Carlo step, one per species.
Implementations